@@ -1,5 +1,5 @@
 #!/bin/bash
-# $Id: f070a6f443e458b6b66d71f2f711762b0dd19ce5 $
+# $Id: b232c3c675ec7918ab0d4e6b942e3208a31a45f2 $
 
 determine_kernel_arch() {
 	[ -z "${VER}" ] && gen_die "Cannot determine KERNEL_ARCH without \$VER!"
@@ -23,6 +23,12 @@ determine_kernel_arch() {
 				fi
 			fi
 			;;
+		riscv|riscv64*)
+			KERNEL_ARCH=riscv
+			;;
+		s390*)
+			KERNEL_ARCH=s390
+			;;
 		x86)
 			if [ "${VER}" -ge "3" ]
 			then
