@@ -1,5 +1,5 @@
 #!/bin/bash
-# $Id: 17f9eafb1a9c972cd72606f02d712d95b6541ca3 $
+# $Id: 5d3e3125c48fe3e1072e866247127c288701ea27 $
 
 # Fills variable KERNEL_CONFIG
 determine_kernel_config_file() {
@@ -25,6 +25,7 @@ determine_kernel_config_file() {
 		local -a kconfig_candidates
 
 		local -a gk_kconfig_candidates
+		gk_kconfig_candidates+=( "${KERNEL_MODULES_PREFIX%/}/lib/modules/${KV}/source/.config" )
 		gk_kconfig_candidates+=( "${GK_SHARE}/arch/${ARCH}/kernel-config-${KV}" )
 		gk_kconfig_candidates+=( "${GK_SHARE}/arch/${ARCH}/kernel-config-${VER}.${PAT}" )
 		gk_kconfig_candidates+=( "${GK_SHARE}/arch/${ARCH}/generated-config" )
@@ -442,14 +443,14 @@ config_kernel() {
 		local cfg_CONFIG_MODULE_COMPRESS_XZ=$(kconfig_get_opt "${KERNEL_OUTPUTDIR}/.config" "CONFIG_MODULE_COMPRESS_XZ")
 		if isTrue "${cfg_CONFIG_MODULE_COMPRESS_GZIP}"
 		then
-			depmod_GZIP=$(/sbin/depmod -V | tr ' ' '\n' | awk '/ZLIB/{print $1; exit}')
+			depmod_GZIP=$(depmod -V | tr ' ' '\n' | awk '/ZLIB/{print $1; exit}')
 			if [[ "${depmod_GZIP}" != "+ZLIB" ]]
 			then
 				gen_die 'depmod does not support ZLIB/GZIP, cannot build with CONFIG_MODULE_COMPRESS_GZIP'
 			fi
 		elif isTrue "${cfg_CONFIG_MODULE_COMPRESS_XZ}"
 		then
-			depmod_XZ=$(/sbin/depmod -V | tr ' ' '\n' | awk '/XZ/{print $1; exit}')
+			depmod_XZ=$(depmod -V | tr ' ' '\n' | awk '/XZ/{print $1; exit}')
 			if [[ "${depmod_XZ}" != "+XZ" ]]
 			then
 				gen_die 'depmod does not support XZ, cannot build with CONFIG_MODULE_COMPRESS_XZ'
